==> cms-db_v0.5.1.tar.gz: template.class.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

class template {

	var $tmp_file;
	var $error;
	var $content;

	function template($file, $error = "Die Template-Datei konnte nicht ge&ouml;ffnet werden!") {
		$this->tmp_file = $file;
		$this->error = $error;
		$this->content = "";
	}

	function readtemplate() {
		$file = @fopen($this->tmp_file, "r");
			if(!$file) {
			echo $this->error;
		} else {
			while(!feof($file)) {
				$temp = fgets($file, 4096);
				$this->content .= $temp;
			}
		}
	}

	function replace($title, $value) {
		// Alle %%TITLE%% durch VALUE ersetzen
		$this->content = str_replace('%%'.$title.'%%', $value, $this->content);
	}

	function makeRedirects() {
		// Alle %%REDIRECT-XXX%% durch function VALUE(TEXT) ersetzen
		$this->content = preg_replace_callback("/%%REDIRECT-(.*)%%/Usi", "doRedirect", $this->content);
	}

	function makeIncludes() {
		// Alle %%INCLUDE-XXX%% durch function VALUE(TEXT) ersetzen
		$this->content = preg_replace_callback("/%%INCLUDE-(.*)%%/Usi", "doInclude", $this->content);
	}

	function addToHead($value) {
		$this->content = str_replace("</head>", $value."\n</head>", $this->content);
	}

	function addBefore($title, $value) {
		$this->content = str_replace($title, $value.$title, $this->content);
	}

	function addAfter($title, $value) {
		$this->content = str_replace($title, $title.$value, $this->content);
	}

	function parse() {
		echo $this->content;
	}

	function hasToBeReplaced($foo) {
		$pos = strpos($this->content, '%%'.$foo.'%%');
		if ($pos === false) {
			return false;
		} else {
			return true;
		}
	}

}
?>

==> cms-db_v0.6.tar.gz: template.class.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

class template {

	var $tmp_file;
	var $error;
	var $content;

	function template($file, $error = '<b>Fatal Error:</b> Couldn\'t open template file.') {
		$this->tmp_file = $file;
		$this->error = $error;
		$this->content = "";
	}

	function readtemplate() {
		$file = @fopen($this->tmp_file, "r");
			if(!$file) {
			echo $this->error;
		} else {
			while(!feof($file)) {
				$temp = fgets($file, 4096);
				$this->content .= $temp;
			}
		}
	}

	function replace($title, $value) {
		// Alle %%TITLE%% durch VALUE ersetzen
		$this->content = str_replace('%%'.$title.'%%', $value, $this->content);
	}

	function replace_regex($title, $value) {
		// Alle TITLE mit regulären Ausdrücken durch VALUE ersetzen
		$this->content = preg_replace($title, $value, $this->content);
	}

	function makeRedirects() {
		// Alle %%REDIRECT-XXX%% durch function VALUE(TEXT) ersetzen
		$this->content = preg_replace_callback("/%%REDIRECT-(.*)%%/U", "doRedirect", $this->content);
	}

	function makeIncludes() {
		// Alle %%INCLUDE-XXX%% durch function VALUE(TEXT) ersetzen
		$this->content = preg_replace_callback(
			"/<p>(\s*)%%INCLUDE-(.*)%%(\s*)<\/p>/U",
			create_function(
				'$match',
				'return doInclude($match[2]);'
			),
			$this->content
		);
		$this->content = preg_replace_callback(
			"/%%INCLUDE-(.*)%%/U",
			create_function(
				'$match',
				'return doInclude($match[1]);'
			),
			$this->content
		);
	}

	function addToHead($value) {
		$this->content = str_replace("</head>", $value."\n</head>", $this->content);
	}

	function addBefore($title, $value) {
		$this->content = str_replace($title, $value.$title, $this->content);
	}

	function addAfter($title, $value) {
		$this->content = str_replace($title, $title.$value, $this->content);
	}

	function parse() {
		echo $this->content;
	}

	function hasToBeReplaced($foo) {
		$pos = strpos($this->content, '%%'.$foo.'%%');
		if ($pos === false) {
			return false;
		} else {
			return true;
		}
	}

}
?>
